Test — Pykaryote 1.1.0d documentation

### Navigation

- index
- modules |
- previous |
- Pykaryote 1.1.0d documentation »
- Modules »

# Test

## Documentation

class `pykaryote.test.test.` `TestAnalyzerQuickRead`(methodName='runTest')

  Tests pykaryote.utils.analysis.Analyzer.quick_read()

  Tests are focused on calls where mode=’threshold’, which is used to gather data on how many generations it takes a metric to reach a threshold value.

  Test coverage is very minimal.

  `test_blanks`()

    Make sure the right number of blanks is reported.

  `test_complexity`()

    Make sure complexity_avg is right.

  `test_means`()

    Make sure the correct means are reported.

  `test_shape`()

    Make sure the resulting data is the right shape.

  `test_variable_length_data`()

    Test that data with varying length (number of generations) is handled correctly.

    For simulations where a time or complexity limit is used instead of a generation limit.

class `pykaryote.test.test.` `TestEnvironment`(methodName='runTest')

  Tests pykaryote.sim.environment.Environment.

  Tests focus on correct creation of the environment grid.

  `test_make_flat_grid`()

    Tests Environment._make_flat_grid()

  `test_make_gaussian_grid`()

    Tests Environment._make_gaussian_grid()

class `pykaryote.test.test.` `TestEnvironmentDraw`(methodName='runTest')

  Tests pykaryote.utils.environment_draw.

class `pykaryote.test.test.` `TestReadComparison`(methodName='runTest')

  Tests the comparison.get_config() method, which reads comparison configuration files.

  `test_get_config`()

    Tests comparison.get_config(), which reads a comparison config file.

class `pykaryote.test.test.` `TestTimeSpentInGaussian`(methodName='runTest')

  Tests the saving and graphing of data about how long each organism spent in each chemical mound/gaussian.

  `tearDown`()

    Removes simulation data.

  `test_flat_environment`()

    Tests plotting with a flat environment.

    Since there are no gaussians, no data should be recorded, and the graph should be blank.

  `test_plot_time_spent_in_gaussian`()

    Test the plotting of `time_spent_in_gaussian` data.

  `test_time_spent_in_gaussian`()

    Ensures that the time_spent_in_gaussian data file is correct.

    Checks array dimensions. Checks that array sums to gv.generation_length.

`pykaryote.test.test.` `run`()

  Runs unit tests with a command line interface.

### Navigation

- index
- modules |
- previous |
- Pykaryote 1.1.0d documentation »
- Modules »